@@ -3,6 +3,6 @@ from .tokenization import RecconEmotionEntailmentTokenizer
 from .modeling import RecconEmotionEntailmentModel
 from .preprocess import RecconEmotionEntailmentPreprocessor
 from .postprocess import RecconEmotionEntailmentPostprocessor
-from .train import train
+from .train import train_model
 from .eval import evaluate
 from .data_class import RecconEmotionEntailmentArguments
