@@ -84,13 +84,14 @@ class RstPointerSegmenterModel(RstPointerSegmenterPreTrainedModel):
         self.dropout = nn.Dropout(config.dropout_prob)
         self.embedding, self.word_dim = initialize_elmo(config.elmo_size)
 
-        if self.rnn_type in ['LSTM', 'GRU']:
+        if self.rnn_type in ["LSTM", "GRU"]:
             self.decoder_rnn = getattr(nn, self.rnn_type)(
                 input_size=2 * self.hidden_dim if self.use_bilstm else self.hidden_dim,
                 hidden_size=2 * self.hidden_dim if self.use_bilstm else self.hidden_dim,
                 num_layers=self.num_rnn_layers,
                 dropout=self.dropout_prob,
-                batch_first=True)
+                batch_first=True,
+            )
 
             self.encoder_rnn = getattr(nn, self.rnn_type)(
                 input_size=self.word_dim,
@@ -98,9 +99,10 @@ class RstPointerSegmenterModel(RstPointerSegmenterPreTrainedModel):
                 num_layers=self.num_rnn_layers,
                 bidirectional=self.use_bilstm,
                 dropout=self.dropout_prob,
-                batch_first=True)
+                batch_first=True,
+            )
         else:
-            raise ValueError('rnn_type should be one of [\'LSTM\', \'GRU\'].')
+            raise ValueError("rnn_type should be one of ['LSTM', 'GRU'].")
 
         if self.use_bilstm:
             self.num_encoder_bi = 2
@@ -108,19 +110,27 @@ class RstPointerSegmenterModel(RstPointerSegmenterPreTrainedModel):
             self.num_encoder_bi = 1
 
     def init_hidden(self, hsize, batchsize):
-        if self.rnn_type == 'LSTM':
-            h_0 = Variable(torch.zeros(self.num_encoder_bi * self.num_rnn_layers, batchsize, hsize)).to(self.device)
-            c_0 = Variable(torch.zeros(self.num_encoder_bi * self.num_rnn_layers, batchsize, hsize)).to(self.device)
+        if self.rnn_type == "LSTM":
+            h_0 = Variable(
+                torch.zeros(self.num_encoder_bi * self.num_rnn_layers, batchsize, hsize)
+            ).to(self.device)
+            c_0 = Variable(
+                torch.zeros(self.num_encoder_bi * self.num_rnn_layers, batchsize, hsize)
+            ).to(self.device)
 
             return h_0, c_0
         else:
-            h_0 = Variable(torch.zeros(self.num_encoder_bi * self.num_rnn_layers, batchsize, hsize)).to(self.device)
+            h_0 = Variable(
+                torch.zeros(self.num_encoder_bi * self.num_rnn_layers, batchsize, hsize)
+            ).to(self.device)
 
             return h_0
 
     def _run_rnn_packed(self, cell, x, x_lens, h=None):
         # Sort first if ONNX exportability is needed
-        x_packed = R.pack_padded_sequence(x, x_lens, batch_first=True, enforce_sorted=False)
+        x_packed = R.pack_padded_sequence(
+            x, x_lens, batch_first=True, enforce_sorted=False
+        )
 
         if h is not None:
             output, h = cell(x_packed, h)
@@ -132,12 +142,16 @@ class RstPointerSegmenterModel(RstPointerSegmenterPreTrainedModel):
         return output, h
 
     def pointer_encoder(self, sentences_ids, sentences_lens):
-        batch_norm = nn.BatchNorm1d(self.word_dim, affine=False, track_running_stats=False)
+        batch_norm = nn.BatchNorm1d(
+            self.word_dim, affine=False, track_running_stats=False
+        )
 
         batch_size = len(sentences_ids)
 
         embeddings = self.embedding(sentences_ids)
-        batch_x_elmo = embeddings['elmo_representations'][0]  # two layers output  [batch,length,d_elmo]
+        batch_x_elmo = embeddings["elmo_representations"][
+            0
+        ]  # two layers output  [batch,length,d_elmo]
 
         x = batch_x_elmo
         if self.is_batch_norm:
@@ -148,8 +162,9 @@ class RstPointerSegmenterModel(RstPointerSegmenterPreTrainedModel):
         x = self.dropout(x)
 
         encoder_lstm_co_h_o = self.init_hidden(self.hidden_dim, batch_size)
-        output_encoder, hidden_states_encoder = self._run_rnn_packed(self.encoder_rnn, x, sentences_lens,
-                                                                     encoder_lstm_co_h_o)  # batch_first=True
+        output_encoder, hidden_states_encoder = self._run_rnn_packed(
+            self.encoder_rnn, x, sentences_lens, encoder_lstm_co_h_o
+        )  # batch_first=True
         output_encoder = output_encoder.contiguous()
         output_encoder = self.dropout(output_encoder)
 
@@ -206,21 +221,37 @@ class RstPointerSegmenterModel(RstPointerSegmenterPreTrainedModel):
             cur_start_boundaries = []
             cur_align_matrix = []
 
-            if self.rnn_type == 'LSTM':  # need h_end,c_end
-                h_end = h_end[0].permute(1, 0, 2).contiguous().view(batch_size, self.num_rnn_layers, -1)
-                c_end = h_end[1].permute(1, 0, 2).contiguous().view(batch_size, self.num_rnn_layers, -1)
+            if self.rnn_type == "LSTM":  # need h_end,c_end
+                h_end = (
+                    h_end[0]
+                    .permute(1, 0, 2)
+                    .contiguous()
+                    .view(batch_size, self.num_rnn_layers, -1)
+                )
+                c_end = (
+                    h_end[1]
+                    .permute(1, 0, 2)
+                    .contiguous()
+                    .view(batch_size, self.num_rnn_layers, -1)
+                )
 
                 cur_h0 = h_end[i].unsqueeze(0).permute(1, 0, 2)
                 cur_c0 = c_end[i].unsqueeze(0).permute(1, 0, 2)
 
                 h_pass = (cur_h0, cur_c0)
             else:  # only need h_end
-                h_end = h_end.permute(1, 0, 2).contiguous().view(batch_size, self.num_rnn_layers, -1)
+                h_end = (
+                    h_end.permute(1, 0, 2)
+                    .contiguous()
+                    .view(batch_size, self.num_rnn_layers, -1)
+                )
                 cur_h0 = h_end[i].unsqueeze(0).permute(1, 0, 2)
                 h_pass = cur_h0
 
             loop_hc = h_pass
-            loop_in = cur_encoder_hn[0, :].unsqueeze(0).unsqueeze(0)  # [ 1, 1, encoder_hidden_size] (first start)
+            loop_in = (
+                cur_encoder_hn[0, :].unsqueeze(0).unsqueeze(0)
+            )  # [ 1, 1, encoder_hidden_size] (first start)
 
             cur_start_boundary = 0
             loop_j = 0
@@ -230,7 +261,9 @@ class RstPointerSegmenterModel(RstPointerSegmenterPreTrainedModel):
 
                 predict_range = list(range(cur_start_boundary, cur_len))
                 cur_encoder_hn_back = cur_encoder_hn[predict_range, :]
-                cur_logits, cur_weights = self.pointer_layer(cur_encoder_hn_back, loop_o.squeeze(0).squeeze(0))
+                cur_logits, cur_weights = self.pointer_layer(
+                    cur_encoder_hn_back, loop_o.squeeze(0).squeeze(0)
+                )
 
                 cur_align_vector = np.zeros(cur_len)
                 cur_align_vector[predict_range] = cur_weights.data.cpu().numpy()[0]
@@ -247,8 +280,11 @@ class RstPointerSegmenterModel(RstPointerSegmenterPreTrainedModel):
                     else:
                         cur_ground_y = cur_y_index[loop_j]
 
-                    cur_ground_y_var = Variable(torch.LongTensor([max(0, int(cur_ground_y) - cur_start_boundary)])).to(
-                        self.device)
+                    cur_ground_y_var = Variable(
+                        torch.LongTensor(
+                            [max(0, int(cur_ground_y) - cur_start_boundary)]
+                        )
+                    ).to(self.device)
 
                     batch_loss += loss_function(cur_logits, cur_ground_y_var)
 
@@ -260,7 +296,9 @@ class RstPointerSegmenterModel(RstPointerSegmenterPreTrainedModel):
                 else:
                     cur_end_boundaries.append(ori_pred_index)
 
-                    loop_in = cur_encoder_hn[ori_pred_index + 1, :].unsqueeze(0).unsqueeze(0)
+                    loop_in = (
+                        cur_encoder_hn[ori_pred_index + 1, :].unsqueeze(0).unsqueeze(0)
+                    )
                     cur_start_boundaries.append(cur_start_boundary)
 
                     cur_start_boundary = ori_pred_index + 1  # start =  pred_end + 1
@@ -275,7 +313,12 @@ class RstPointerSegmenterModel(RstPointerSegmenterPreTrainedModel):
 
         batch_loss = batch_loss / total_loops if batch_y is not None else None
 
-        return batch_start_boundaries, batch_end_boundaries, batch_align_matrix, batch_loss
+        return (
+            batch_start_boundaries,
+            batch_end_boundaries,
+            batch_align_matrix,
+            batch_loss,
+        )
 
     def forward(self, tokenized_sentence_ids, sentence_lens, labels=None):
         """
@@ -287,9 +330,12 @@ class RstPointerSegmenterModel(RstPointerSegmenterPreTrainedModel):
         Returns:
             output (:class:`~sgnlp.models.rst_pointer.modeling.RstPointerSegmenterModelOutput`)
         """
-        encoder_h_n, encoder_h_end = self.pointer_encoder(tokenized_sentence_ids, sentence_lens)
-        start_boundaries, end_boundaries, _, loss = self.decoder(encoder_h_n, encoder_h_end,
-                                                                 sentence_lens, labels)
+        encoder_h_n, encoder_h_end = self.pointer_encoder(
+            tokenized_sentence_ids, sentence_lens
+        )
+        start_boundaries, end_boundaries, _, loss = self.decoder(
+            encoder_h_n, encoder_h_end, sentence_lens, labels
+        )
         return RstPointerSegmenterModelOutput(loss, start_boundaries, end_boundaries)
 
 
@@ -305,6 +351,7 @@ class RstPointerParserPreTrainedModel(PreTrainedModel):
     An abstract class to handle weights initialization and a simple interface for downloading and loading pretrained
     models.
     """
+
     config_class = RstPointerParserConfig
     base_model_prefix = "rst_pointer_parser"
 
@@ -361,24 +408,34 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
             word_dim=self.word_dim,
             hidden_size=self.hidden_size,
             rnn_layers=self.rnn_layers,
-            dropout=config.dropout_e)
+            dropout=config.dropout_e,
+        )
         self.decoder = DecoderRNN(
             input_size=self.decoder_input_size,
             hidden_size=self.hidden_size,
             rnn_layers=self.rnn_layers,
-            dropout=config.dropout_d)
+            dropout=config.dropout_d,
+        )
         self.pointer = PointerAtten(
-            atten_model=self.atten_model,
-            hidden_size=self.hidden_size)
+            atten_model=self.atten_model, hidden_size=self.hidden_size
+        )
         self.classifier = LabelClassifier(
             input_size=self.classifier_input_size,
             classifier_hidden_size=self.classifier_hidden_size,
             classes_label=self.classes_label,
             bias=self.classifier_bias,
-            dropout=config.dropout_c)
+            dropout=config.dropout_c,
+        )
 
-    def forward(self, input_sentence_ids, edu_breaks, sentence_lengths,
-                label_index=None, parsing_index=None, generate_splits=True):
+    def forward(
+        self,
+        input_sentence_ids,
+        edu_breaks,
+        sentence_lengths,
+        label_index=None,
+        parsing_index=None,
+        generate_splits=True,
+    ):
         """
         Args:
             input_sentence_ids: Input sentence IDs.
@@ -435,23 +492,35 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                 #  Directly run the classifier to obain predicted label
                 input_left = cur_encoder_outputs[0].unsqueeze(0)
                 input_right = cur_encoder_outputs[1].unsqueeze(0)
-                relation_weights, log_relation_weights = self.classifier(input_left, input_right)
+                relation_weights, log_relation_weights = self.classifier(
+                    input_left, input_right
+                )
                 _, topindex = relation_weights.topk(1)
                 label_predict = int(topindex[0][0])
                 tree_batch.append([0])
                 label_batch.append([label_predict])
 
                 if calculate_loss:
-                    loss_label_batch = loss_label_batch + loss_function(log_relation_weights, cur_label_index)
+                    loss_label_batch = loss_label_batch + loss_function(
+                        log_relation_weights, cur_label_index
+                    )
                     loop_label_batch = loop_label_batch + 1
 
                 if generate_splits:
-                    nuclearity_left, nuclearity_right, relation_left, relation_right = \
-                        get_relation_and_nucleus(label_predict)
+                    (
+                        nuclearity_left,
+                        nuclearity_right,
+                        relation_left,
+                        relation_right,
+                    ) = get_relation_and_nucleus(label_predict)
 
                     split = DiscourseTreeSplit(
-                        left=DiscourseTreeNode(span=(0, 0), ns_type=nuclearity_left, label=relation_left),
-                        right=DiscourseTreeNode(span=(1, 1), ns_type=nuclearity_right, label=relation_right)
+                        left=DiscourseTreeNode(
+                            span=(0, 0), ns_type=nuclearity_left, label=relation_left
+                        ),
+                        right=DiscourseTreeNode(
+                            span=(1, 1), ns_type=nuclearity_right, label=relation_right
+                        ),
                     )
 
                     splits_batch.append([split])
@@ -462,7 +531,7 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                 cur_encoder_outputs = encoder_outputs[i][edu_breaks[i]]
 
                 edu_index = [x for x in range(len(cur_encoder_outputs))]
-                stacks = ['__StackRoot__', edu_index]
+                stacks = ["__StackRoot__", edu_index]
 
                 # cur_decoder_input: [1,1,hidden_size]
                 # Alternative way is to take the last one as the input. You need to prepare data accordingly for training
@@ -481,7 +550,7 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                 if self.highorder:
                     cur_sibling = {}
 
-                while stacks[-1] != '__StackRoot__':
+                while stacks[-1] != "__StackRoot__":
                     stack_head = stacks[-1]
 
                     if len(stack_head) < 3:
@@ -489,7 +558,9 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                         # Predict relation label
                         input_left = cur_encoder_outputs[stack_head[0]].unsqueeze(0)
                         input_right = cur_encoder_outputs[stack_head[-1]].unsqueeze(0)
-                        relation_weights, log_relation_weights = self.classifier(input_left, input_right)
+                        relation_weights, log_relation_weights = self.classifier(
+                            input_left, input_right
+                        )
                         _, topindex = relation_weights.topk(1)
                         label_predict = int(topindex[0][0])
                         cur_label.append(label_predict)
@@ -499,7 +570,9 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                         cur_tree.append(stack_head[0])
 
                         # To keep decoder hidden states consistent
-                        _, cur_decoder_hidden = self.decoder(cur_decoder_input, cur_decoder_hidden)
+                        _, cur_decoder_hidden = self.decoder(
+                            cur_decoder_input, cur_decoder_hidden
+                        )
 
                         # Align ground truth label
                         if calculate_loss:
@@ -508,22 +581,33 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                             else:
                                 cur_label_true = cur_label_index[loop_index]
 
-                            loss_label_batch = loss_label_batch + loss_function(log_relation_weights,
-                                                                                cur_label_true.unsqueeze(0))
+                            loss_label_batch = loss_label_batch + loss_function(
+                                log_relation_weights, cur_label_true.unsqueeze(0)
+                            )
                             loop_label_batch = loop_label_batch + 1
                         loop_index = loop_index + 1
                         del stacks[-1]
 
                         if generate_splits:
                             # To generate a tree structure
-                            nuclearity_left, nuclearity_right, relation_left, relation_right = \
-                                get_relation_and_nucleus(label_predict)
+                            (
+                                nuclearity_left,
+                                nuclearity_right,
+                                relation_left,
+                                relation_right,
+                            ) = get_relation_and_nucleus(label_predict)
 
                             cur_split = DiscourseTreeSplit(
-                                left=DiscourseTreeNode(span=(stack_head[0], stack_head[0]), ns_type=nuclearity_left,
-                                                       label=relation_left),
-                                right=DiscourseTreeNode(span=(stack_head[-1], stack_head[-1]), ns_type=nuclearity_right,
-                                                        label=relation_right)
+                                left=DiscourseTreeNode(
+                                    span=(stack_head[0], stack_head[0]),
+                                    ns_type=nuclearity_left,
+                                    label=relation_left,
+                                ),
+                                right=DiscourseTreeNode(
+                                    span=(stack_head[-1], stack_head[-1]),
+                                    ns_type=nuclearity_right,
+                                    label=relation_right,
+                                ),
                             )
 
                             splits.append(cur_split)
@@ -531,38 +615,81 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                     else:
                         # Length of stack_head >= 3
                         # Alternative way is to take the last one as the input. You need to prepare data accordingly for training
-                        cur_decoder_input = cur_encoder_outputs[stack_head[0]].unsqueeze(0).unsqueeze(0)
+                        cur_decoder_input = (
+                            cur_encoder_outputs[stack_head[0]].unsqueeze(0).unsqueeze(0)
+                        )
 
                         if self.highorder:
                             if loop_index != 0:
                                 # Incorporate Parents information
-                                cur_decoder_input_P = cur_encoder_outputs[stack_head[-1]]
+                                cur_decoder_input_P = cur_encoder_outputs[
+                                    stack_head[-1]
+                                ]
                                 # To incorporate Sibling information
                                 if str(stack_head) in cur_sibling.keys():
-                                    cur_decoder_input_S = cur_encoder_outputs[cur_sibling[str(stack_head)]]
+                                    cur_decoder_input_S = cur_encoder_outputs[
+                                        cur_sibling[str(stack_head)]
+                                    ]
 
                                     inputs_all = torch.cat(
-                                        (cur_decoder_input.squeeze(0), cur_decoder_input_S.unsqueeze(0), \
-                                         cur_decoder_input_P.unsqueeze(0)), 0)
+                                        (
+                                            cur_decoder_input.squeeze(0),
+                                            cur_decoder_input_S.unsqueeze(0),
+                                            cur_decoder_input_P.unsqueeze(0),
+                                        ),
+                                        0,
+                                    )
                                     new_inputs_all = torch.matmul(
-                                        F.softmax(torch.matmul(inputs_all, inputs_all.transpose(0, 1)), 0), inputs_all)
-                                    cur_decoder_input = new_inputs_all[0, :] + new_inputs_all[1, :] + new_inputs_all[2,
-                                                                                                      :]
-                                    cur_decoder_input = cur_decoder_input.unsqueeze(0).unsqueeze(0)
+                                        F.softmax(
+                                            torch.matmul(
+                                                inputs_all, inputs_all.transpose(0, 1)
+                                            ),
+                                            0,
+                                        ),
+                                        inputs_all,
+                                    )
+                                    cur_decoder_input = (
+                                        new_inputs_all[0, :]
+                                        + new_inputs_all[1, :]
+                                        + new_inputs_all[2, :]
+                                    )
+                                    cur_decoder_input = cur_decoder_input.unsqueeze(
+                                        0
+                                    ).unsqueeze(0)
 
                                     # cur_decoder_input = cur_decoder_input + cur_decoder_input_P + cur_decoder_input_S
                                 else:
                                     inputs_all = torch.cat(
-                                        (cur_decoder_input.squeeze(0), cur_decoder_input_P.unsqueeze(0)), 0)
+                                        (
+                                            cur_decoder_input.squeeze(0),
+                                            cur_decoder_input_P.unsqueeze(0),
+                                        ),
+                                        0,
+                                    )
                                     new_inputs_all = torch.matmul(
-                                        F.softmax(torch.matmul(inputs_all, inputs_all.transpose(0, 1)), 0), inputs_all)
-                                    cur_decoder_input = new_inputs_all[0, :] + new_inputs_all[1, :]
-                                    cur_decoder_input = cur_decoder_input.unsqueeze(0).unsqueeze(0)
+                                        F.softmax(
+                                            torch.matmul(
+                                                inputs_all, inputs_all.transpose(0, 1)
+                                            ),
+                                            0,
+                                        ),
+                                        inputs_all,
+                                    )
+                                    cur_decoder_input = (
+                                        new_inputs_all[0, :] + new_inputs_all[1, :]
+                                    )
+                                    cur_decoder_input = cur_decoder_input.unsqueeze(
+                                        0
+                                    ).unsqueeze(0)
 
                         # Predict the parsing tree break
-                        cur_decoder_output, cur_decoder_hidden = self.decoder(cur_decoder_input, cur_decoder_hidden)
-                        atten_weights, log_atten_weights = self.pointer(cur_encoder_outputs[stack_head[:-1]],
-                                                                        cur_decoder_output.squeeze(0).squeeze(0))
+                        cur_decoder_output, cur_decoder_hidden = self.decoder(
+                            cur_decoder_input, cur_decoder_hidden
+                        )
+                        atten_weights, log_atten_weights = self.pointer(
+                            cur_encoder_outputs[stack_head[:-1]],
+                            cur_decoder_output.squeeze(0).squeeze(0),
+                        )
                         _, topindex_tree = atten_weights.topk(1)
                         tree_predict = int(topindex_tree[0][0]) + stack_head[0]
                         cur_tree.append(tree_predict)
@@ -570,7 +697,9 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                         # Predict the Label
                         input_left = cur_encoder_outputs[tree_predict].unsqueeze(0)
                         input_right = cur_encoder_outputs[stack_head[-1]].unsqueeze(0)
-                        relation_weights, log_relation_weights = self.classifier(input_left, input_right)
+                        relation_weights, log_relation_weights = self.classifier(
+                            input_left, input_right
+                        )
                         _, topindex_label = relation_weights.topk(1)
                         label_predict = int(topindex_label[0][0])
                         cur_label.append(label_predict)
@@ -584,23 +713,28 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                                 cur_label_true = cur_label_index[loop_index]
                                 cur_tree_true = cur_parsing_index[loop_index]
 
-                            temp_ground = max(0, (int(cur_tree_true) - int(stack_head[0])))
+                            temp_ground = max(
+                                0, (int(cur_tree_true) - int(stack_head[0]))
+                            )
                             if temp_ground >= (len(stack_head) - 1):
                                 temp_ground = stack_head[-2] - stack_head[0]
                             # Compute Tree Loss
                             cur_ground_index = torch.tensor([temp_ground])
                             cur_ground_index = cur_ground_index.to(self.device)
-                            loss_tree_batch = loss_tree_batch + loss_function(log_atten_weights, cur_ground_index)
+                            loss_tree_batch = loss_tree_batch + loss_function(
+                                log_atten_weights, cur_ground_index
+                            )
 
                             # Compute Classifier Loss
-                            loss_label_batch = loss_label_batch + loss_function(log_relation_weights,
-                                                                                cur_label_true.unsqueeze(0))
+                            loss_label_batch = loss_label_batch + loss_function(
+                                log_relation_weights, cur_label_true.unsqueeze(0)
+                            )
                             loop_label_batch = loop_label_batch + 1
                             loop_tree_batch = loop_tree_batch + 1
 
                         # Stacks stuff
-                        stack_down = stack_head[(tree_predict - stack_head[0] + 1):]
-                        stack_top = stack_head[:(tree_predict - stack_head[0] + 1)]
+                        stack_down = stack_head[(tree_predict - stack_head[0] + 1) :]
+                        stack_top = stack_head[: (tree_predict - stack_head[0] + 1)]
                         del stacks[-1]
                         loop_index = loop_index + 1
 
@@ -616,14 +750,24 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                             stacks.append(stack_top)
 
                         if generate_splits:
-                            nuclearity_left, nuclearity_right, relation_left, relation_right = \
-                                get_relation_and_nucleus(label_predict)
+                            (
+                                nuclearity_left,
+                                nuclearity_right,
+                                relation_left,
+                                relation_right,
+                            ) = get_relation_and_nucleus(label_predict)
 
                             cur_split = DiscourseTreeSplit(
-                                left=DiscourseTreeNode(span=(stack_head[0], tree_predict), ns_type=nuclearity_left,
-                                                       label=relation_left),
-                                right=DiscourseTreeNode(span=(tree_predict + 1, stack_head[-1]),
-                                                        ns_type=nuclearity_right, label=relation_right)
+                                left=DiscourseTreeNode(
+                                    span=(stack_head[0], tree_predict),
+                                    ns_type=nuclearity_left,
+                                    label=relation_left,
+                                ),
+                                right=DiscourseTreeNode(
+                                    span=(tree_predict + 1, stack_head[-1]),
+                                    ns_type=nuclearity_right,
+                                    label=relation_right,
+                                ),
                             )
 
                             splits.append(cur_split)
@@ -645,11 +789,23 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
             loss_tree_batch = None
             loss_label_batch = None
 
-        return RstPointerParserModelOutput(loss_tree_batch, loss_label_batch,
-                                           (splits_batch if generate_splits else None))
+        return RstPointerParserModelOutput(
+            loss_tree_batch,
+            loss_label_batch,
+            (splits_batch if generate_splits else None),
+        )
 
-    def forward_train(self, input_sentence_ids_batch, edu_breaks_batch, label_index_batch, parsing_index_batch,
-                      decoder_input_index_batch, parents_index_batch, sibling_index_batch, sentence_lengths):
+    def forward_train(
+        self,
+        input_sentence_ids_batch,
+        edu_breaks_batch,
+        label_index_batch,
+        parsing_index_batch,
+        decoder_input_index_batch,
+        parents_index_batch,
+        sibling_index_batch,
+        sentence_lengths,
+    ):
         # TODO: This function should ideally be combined with the forward function.
         #   There are significant overlap in code, but also some significant differences in the logic
         #   which makes refactoring them difficult.
@@ -687,13 +843,17 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                 input_right = cur_encoder_outputs[1].unsqueeze(0)
                 _, log_relation_weights = self.classifier(input_left, input_right)
 
-                loss_label_batch = loss_label_batch + loss_function(log_relation_weights, cur_label_index)
+                loss_label_batch = loss_label_batch + loss_function(
+                    log_relation_weights, cur_label_index
+                )
                 loop_label_batch = loop_label_batch + 1
 
             else:
                 # Take the last hidden state of an EDU as the representation of this EDU
                 # The dimension: [NO_EDU,hidden_size]
-                cur_encoder_outputs = encoder_outputs[i][edu_breaks_batch[i]].to(self.device)
+                cur_encoder_outputs = encoder_outputs[i][edu_breaks_batch[i]].to(
+                    self.device
+                )
 
                 # Obtain last hidden state of encoder
                 temp = torch.transpose(last_hiddenstates, 0, 1)[i].unsqueeze(0)
@@ -706,8 +866,9 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                     cur_decoder_inputs_P[0] = 0
 
                     # Incorporate sibling information
-                    cur_decoder_inputs_S = torch.zeros([len(cur_sibling_index), cur_encoder_outputs.shape[1]]).to(
-                        self.device)
+                    cur_decoder_inputs_S = torch.zeros(
+                        [len(cur_sibling_index), cur_encoder_outputs.shape[1]]
+                    ).to(self.device)
                     for n, s_idx in enumerate(cur_sibling_index):
                         if s_idx != 99:
                             cur_decoder_inputs_S[n] = cur_encoder_outputs[s_idx]
@@ -716,27 +877,41 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                     cur_decoder_inputs = cur_encoder_outputs[cur_decoder_input_index]
 
                     # One-layer self attention
-                    inputs_all = torch.cat((cur_decoder_inputs.unsqueeze(0).transpose(0, 1),
-                                            cur_decoder_inputs_S.unsqueeze(0).transpose(0, 1),
-                                            cur_decoder_inputs_P.unsqueeze(0).transpose(0, 1)), 1)
-                    new_inputs_all = torch.matmul(F.softmax(torch.matmul(inputs_all, inputs_all.transpose(1, 2)), 1),
-                                                  inputs_all)
-                    cur_decoder_inputs = new_inputs_all[:, 0, :] + new_inputs_all[:, 1, :] + new_inputs_all[:, 2, :]
-
+                    inputs_all = torch.cat(
+                        (
+                            cur_decoder_inputs.unsqueeze(0).transpose(0, 1),
+                            cur_decoder_inputs_S.unsqueeze(0).transpose(0, 1),
+                            cur_decoder_inputs_P.unsqueeze(0).transpose(0, 1),
+                        ),
+                        1,
+                    )
+                    new_inputs_all = torch.matmul(
+                        F.softmax(
+                            torch.matmul(inputs_all, inputs_all.transpose(1, 2)), 1
+                        ),
+                        inputs_all,
+                    )
+                    cur_decoder_inputs = (
+                        new_inputs_all[:, 0, :]
+                        + new_inputs_all[:, 1, :]
+                        + new_inputs_all[:, 2, :]
+                    )
 
                 else:
                     cur_decoder_inputs = cur_encoder_outputs[cur_decoder_input_index]
 
                 # Obtain decoder outputs
-                cur_decoder_outputs, _ = self.decoder(cur_decoder_inputs.unsqueeze(0), cur_last_hiddenstates)
+                cur_decoder_outputs, _ = self.decoder(
+                    cur_decoder_inputs.unsqueeze(0), cur_last_hiddenstates
+                )
                 cur_decoder_outputs = cur_decoder_outputs.squeeze(0)
 
                 edu_index = [x for x in range(len(cur_encoder_outputs))]
-                stacks = ['__StackRoot__', edu_index]
+                stacks = ["__StackRoot__", edu_index]
 
                 for j in range(len(cur_decoder_outputs)):
 
-                    if stacks[-1] != '__StackRoot__':
+                    if stacks[-1] != "__StackRoot__":
                         stack_head = stacks[-1]
 
                         if len(stack_head) < 3:
@@ -745,12 +920,19 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                             # relation between these two EDUS
 
                             # Compute Classifier Loss
-                            input_left = cur_encoder_outputs[cur_parsing_index[j]].unsqueeze(0)
-                            input_right = cur_encoder_outputs[stack_head[-1]].unsqueeze(0)
-                            _, log_relation_weights = self.classifier(input_left, input_right)
+                            input_left = cur_encoder_outputs[
+                                cur_parsing_index[j]
+                            ].unsqueeze(0)
+                            input_right = cur_encoder_outputs[stack_head[-1]].unsqueeze(
+                                0
+                            )
+                            _, log_relation_weights = self.classifier(
+                                input_left, input_right
+                            )
 
-                            loss_label_batch = loss_label_batch + loss_function(log_relation_weights,
-                                                                                cur_label_index[j].unsqueeze(0))
+                            loss_label_batch = loss_label_batch + loss_function(
+                                log_relation_weights, cur_label_index[j].unsqueeze(0)
+                            )
 
                             del stacks[-1]
                             loop_label_batch = loop_label_batch + 1
@@ -758,23 +940,40 @@ class RstPointerParserModel(RstPointerParserPreTrainedModel):
                         else:  # Length of stack_head >= 3
                             # Compute Tree Loss
                             # We don't attend to the last EDU of a span to be parsed
-                            _, log_atten_weights = self.pointer(cur_encoder_outputs[stack_head[:-1]],
-                                                                cur_decoder_outputs[j])
-                            cur_ground_index = torch.tensor([int(cur_parsing_index[j]) - int(stack_head[0])])
+                            _, log_atten_weights = self.pointer(
+                                cur_encoder_outputs[stack_head[:-1]],
+                                cur_decoder_outputs[j],
+                            )
+                            cur_ground_index = torch.tensor(
+                                [int(cur_parsing_index[j]) - int(stack_head[0])]
+                            )
                             cur_ground_index = cur_ground_index.to(self.device)
-                            loss_tree_batch = loss_tree_batch + loss_function(log_atten_weights, cur_ground_index)
+                            loss_tree_batch = loss_tree_batch + loss_function(
+                                log_atten_weights, cur_ground_index
+                            )
 
                             # Compute Classifier Loss
-                            input_left = cur_encoder_outputs[cur_parsing_index[j]].unsqueeze(0)
-                            input_right = cur_encoder_outputs[stack_head[-1]].unsqueeze(0)
-                            _, log_relation_weights = self.classifier(input_left, input_right)
+                            input_left = cur_encoder_outputs[
+                                cur_parsing_index[j]
+                            ].unsqueeze(0)
+                            input_right = cur_encoder_outputs[stack_head[-1]].unsqueeze(
+                                0
+                            )
+                            _, log_relation_weights = self.classifier(
+                                input_left, input_right
+                            )
 
-                            loss_label_batch = loss_label_batch + loss_function(log_relation_weights,
-                                                                                cur_label_index[j].unsqueeze(0))
+                            loss_label_batch = loss_label_batch + loss_function(
+                                log_relation_weights, cur_label_index[j].unsqueeze(0)
+                            )
 
                             # Stacks stuff
-                            stack_down = stack_head[(cur_parsing_index[j] - stack_head[0] + 1):]
-                            stack_top = stack_head[:(cur_parsing_index[j] - stack_head[0] + 1)]
+                            stack_down = stack_head[
+                                (cur_parsing_index[j] - stack_head[0] + 1) :
+                            ]
+                            stack_top = stack_head[
+                                : (cur_parsing_index[j] - stack_head[0] + 1)
+                            ]
                             del stacks[-1]
                             loop_label_batch = loop_label_batch + 1
                             loop_tree_batch = loop_tree_batch + 1
