@@ -8,6 +8,7 @@ class DecoderRNN(nn.Module):
     """
     DecoderRNN model to be used in the decoder of the RST Parser network.
     """
+
     def __init__(self, input_size, hidden_size, rnn_layers=6, dropout=0.2):
         super(DecoderRNN, self).__init__()
         self.gru = nn.GRU(
@@ -15,10 +16,12 @@ class DecoderRNN(nn.Module):
             hidden_size,
             rnn_layers,
             batch_first=True,
-            dropout=(0 if rnn_layers == 1 else dropout))
+            dropout=(0 if rnn_layers == 1 else dropout),
+        )
 
-    def forward(self, input_hidden_states: torch.Tensor, last_hidden: torch.Tensor) -> \
-            Tuple[torch.Tensor, torch.Tensor]:
+    def forward(
+        self, input_hidden_states: torch.Tensor, last_hidden: torch.Tensor
+    ) -> Tuple[torch.Tensor, torch.Tensor]:
         """
         Forward pass for decoder RNN.
 
