@@ -10,7 +10,12 @@ import torch
 
 from sgnlp.utils.csv_writer import CsvWriter
 from .data_class import RstPointerParserTrainArgs, RstPointerSegmenterTrainArgs
-from .modeling import RstPointerParserModel, RstPointerParserConfig, RstPointerSegmenterModel, RstPointerSegmenterConfig
+from .modeling import (
+    RstPointerParserModel,
+    RstPointerParserConfig,
+    RstPointerSegmenterModel,
+    RstPointerSegmenterConfig,
+)
 from .modules.type import DiscourseTreeNode, DiscourseTreeSplit
 from .preprocess import RstPreprocessor
 from .utils import parse_args_and_load_config
@@ -35,7 +40,7 @@ def setup(seed):
 def adjust_learning_rate(optimizer, epoch, lr_decay=0.5, lr_decay_epoch=50):
     if (epoch % lr_decay_epoch == 0) and (epoch != 0):
         for param_group in optimizer.param_groups:
-            param_group['lr'] = param_group['lr'] * lr_decay
+            param_group["lr"] = param_group["lr"] * lr_decay
 
 
 # Parser training code
@@ -52,7 +57,7 @@ def get_span_dict(discourse_tree_splits: List[DiscourseTreeSplit]):
 
 
 def get_span_key_and_node_value(node: DiscourseTreeNode):
-    span_key = f'{node.span[0]}-{node.span[1]}'
+    span_key = f"{node.span[0]}-{node.span[1]}"
     node_value = [node.label, node.ns_type]
     return span_key, node_value
 
@@ -76,7 +81,13 @@ def get_measurement(discourse_tree_splits_1, discourse_tree_splits_2):
         if span_dict1[span][1] == span_dict2[span][1]:
             num_correct_nuclearity += 1
 
-    return num_matching_spans, num_correct_relations, num_correct_nuclearity, num_spans_1, num_spans_2
+    return (
+        num_matching_spans,
+        num_correct_relations,
+        num_correct_nuclearity,
+        num_spans_1,
+        num_spans_2,
+    )
 
 
 def get_batch_measure(input_splits_batch, golden_metric_batch):
@@ -89,8 +100,13 @@ def get_batch_measure(input_splits_batch, golden_metric_batch):
     for input_splits, golden_splits in zip(input_splits_batch, golden_metric_batch):
         if input_splits and golden_splits:
             # if both splits have values in the list
-            _num_matching_spans, _num_correct_relations, _num_correct_nuclearity, _num_spans_input, _num_spans_golden \
-                = get_measurement(input_splits, golden_splits)
+            (
+                _num_matching_spans,
+                _num_correct_relations,
+                _num_correct_nuclearity,
+                _num_spans_input,
+                _num_spans_golden,
+            ) = get_measurement(input_splits, golden_splits)
 
             num_matching_spans += _num_matching_spans
             num_correct_relations += _num_correct_relations
@@ -105,10 +121,18 @@ def get_batch_measure(input_splits_batch, golden_metric_batch):
         elif not input_splits and golden_splits:
             num_spans_golden += len(golden_splits) * 2
 
-    return num_matching_spans, num_correct_relations, num_correct_nuclearity, num_spans_input, num_spans_golden
+    return (
+        num_matching_spans,
+        num_correct_relations,
+        num_correct_nuclearity,
+        num_spans_input,
+        num_spans_golden,
+    )
 
 
-def get_micro_measure(correct_span, correct_relation, correct_nuclearity, no_system, no_golden):
+def get_micro_measure(
+    correct_span, correct_relation, correct_nuclearity, no_system, no_golden
+):
     # Compute Micro-average measure
     # Span
     precision_span = correct_span / no_system
@@ -125,13 +149,25 @@ def get_micro_measure(correct_span, correct_relation, correct_nuclearity, no_sys
     recall_nuclearity = correct_nuclearity / no_golden
     f1_nuclearity = (2 * correct_nuclearity) / (no_golden + no_system)
 
-    return (precision_span, recall_span, f1_span), (precision_relation, recall_relation, f1_relation), \
-           (precision_nuclearity, recall_nuclearity, f1_nuclearity)
+    return (
+        (precision_span, recall_span, f1_span),
+        (precision_relation, recall_relation, f1_relation),
+        (precision_nuclearity, recall_nuclearity, f1_nuclearity),
+    )
 
 
 # TODO: Change data sampling
-def get_batch_data_training(input_sentences, edu_breaks, decoder_input, relation_label,
-                            parsing_breaks, golden_metric, parents_index, sibling, batch_size):
+def get_batch_data_training(
+    input_sentences,
+    edu_breaks,
+    decoder_input,
+    relation_label,
+    parsing_breaks,
+    golden_metric,
+    parents_index,
+    sibling,
+    batch_size,
+):
     # change them into np.array
     input_sentences = np.array(input_sentences, dtype="object")
     edu_breaks = np.array(edu_breaks, dtype="object")
@@ -171,12 +207,27 @@ def get_batch_data_training(input_sentences, edu_breaks, decoder_input, relation
     parents_index_batch = parents_index_batch[idx].tolist()
     sibling_batch = sibling_batch[idx].tolist()
 
-    return input_sentences_batch, edu_breaks_batch, decoder_input_batch, relation_label_batch, \
-           parsing_breaks_batch, golden_metric_batch, parents_index_batch, sibling_batch
+    return (
+        input_sentences_batch,
+        edu_breaks_batch,
+        decoder_input_batch,
+        relation_label_batch,
+        parsing_breaks_batch,
+        golden_metric_batch,
+        parents_index_batch,
+        sibling_batch,
+    )
 
 
-def get_batch_data(input_sentences, edu_breaks, decoder_input, relation_label,
-                   parsing_breaks, golden_metric, batch_size):
+def get_batch_data(
+    input_sentences,
+    edu_breaks,
+    decoder_input,
+    relation_label,
+    parsing_breaks,
+    golden_metric,
+    batch_size,
+):
     # change them into np.array
     input_sentences = np.array(input_sentences, dtype="object")
     edu_breaks = np.array(edu_breaks, dtype="object")
@@ -210,11 +261,27 @@ def get_batch_data(input_sentences, edu_breaks, decoder_input, relation_label,
     parsing_breaks_batch = parsing_breaks_batch[idx].tolist()
     golden_metric_batch = golden_metric_batch[idx].tolist()
 
-    return input_sentences_batch, edu_breaks_batch, decoder_input_batch, relation_label_batch, parsing_breaks_batch, golden_metric_batch
+    return (
+        input_sentences_batch,
+        edu_breaks_batch,
+        decoder_input_batch,
+        relation_label_batch,
+        parsing_breaks_batch,
+        golden_metric_batch,
+    )
 
 
-def get_accuracy(model, preprocessor, input_sentences, edu_breaks, decoder_input, relation_label,
-                 parsing_breaks, golden_metric, batch_size):
+def get_accuracy(
+    model,
+    preprocessor,
+    input_sentences,
+    edu_breaks,
+    decoder_input,
+    relation_label,
+    parsing_breaks,
+    golden_metric,
+    batch_size,
+):
     num_loops = int(np.ceil(len(edu_breaks) / batch_size))
 
     loss_tree_all = []
@@ -231,16 +298,26 @@ def get_accuracy(model, preprocessor, input_sentences, edu_breaks, decoder_input
         if end_idx > len(edu_breaks):
             end_idx = len(edu_breaks)
 
-        input_sentences_batch, edu_breaks_batch, _, \
-        relation_label_batch, parsing_breaks_batch, golden_metric_splits_batch = \
-            get_batch_data(input_sentences[start_idx:end_idx],
-                           edu_breaks[start_idx:end_idx],
-                           decoder_input[start_idx:end_idx],
-                           relation_label[start_idx:end_idx],
-                           parsing_breaks[start_idx:end_idx],
-                           golden_metric[start_idx:end_idx], batch_size)
+        (
+            input_sentences_batch,
+            edu_breaks_batch,
+            _,
+            relation_label_batch,
+            parsing_breaks_batch,
+            golden_metric_splits_batch,
+        ) = get_batch_data(
+            input_sentences[start_idx:end_idx],
+            edu_breaks[start_idx:end_idx],
+            decoder_input[start_idx:end_idx],
+            relation_label[start_idx:end_idx],
+            parsing_breaks[start_idx:end_idx],
+            golden_metric[start_idx:end_idx],
+            batch_size,
+        )
 
-        input_sentences_ids_batch, sentence_lengths = preprocessor.get_elmo_char_ids(input_sentences_batch)
+        input_sentences_ids_batch, sentence_lengths = preprocessor.get_elmo_char_ids(
+            input_sentences_batch
+        )
         input_sentences_ids_batch = input_sentences_ids_batch.to(device=model.device)
 
         model_output = model(
@@ -249,14 +326,18 @@ def get_accuracy(model, preprocessor, input_sentences, edu_breaks, decoder_input
             sentence_lengths=sentence_lengths,
             label_index=relation_label_batch,
             parsing_index=parsing_breaks_batch,
-            generate_splits=True
+            generate_splits=True,
         )
 
         loss_tree_all.append(model_output.loss_tree)
         loss_label_all.append(model_output.loss_label)
-        correct_span_batch, correct_relation_batch, correct_nuclearity_batch, \
-        no_system_batch, no_golden_batch = get_batch_measure(model_output.splits,
-                                                             golden_metric_splits_batch)
+        (
+            correct_span_batch,
+            correct_relation_batch,
+            correct_nuclearity_batch,
+            no_system_batch,
+            no_golden_batch,
+        ) = get_batch_measure(model_output.splits, golden_metric_splits_batch)
 
         correct_span = correct_span + correct_span_batch
         correct_relation = correct_relation + correct_relation_batch
@@ -265,13 +346,20 @@ def get_accuracy(model, preprocessor, input_sentences, edu_breaks, decoder_input
         no_golden = no_golden + no_golden_batch
 
     span_points, relation_points, nuclearity_points = get_micro_measure(
-        correct_span, correct_relation, correct_nuclearity, no_system, no_golden)
+        correct_span, correct_relation, correct_nuclearity, no_system, no_golden
+    )
 
-    return np.mean(loss_tree_all), np.mean(loss_label_all), span_points, relation_points, nuclearity_points
+    return (
+        np.mean(loss_tree_all),
+        np.mean(loss_label_all),
+        span_points,
+        relation_points,
+        nuclearity_points,
+    )
 
 
 def train_parser(cfg: RstPointerParserTrainArgs) -> None:
-    logger.info(f'===== Training RST Pointer Parser =====')
+    logger.info(f"===== Training RST Pointer Parser =====")
 
     # Setup
     setup(seed=cfg.seed)
@@ -297,40 +385,87 @@ def train_parser(cfg: RstPointerParserTrainArgs) -> None:
     highorder = cfg.highorder
 
     device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
-    logger.info(f'Device: {device}')
+    logger.info(f"Device: {device}")
 
     # Create directory and files
     os.makedirs(save_dir, exist_ok=True)
-    best_results_writer = CsvWriter(file_path=os.path.join(save_dir, 'best_results.csv'),
-                                    fieldnames=['best_epoch', 'f1_relation', 'precision_relation', 'recall_relation',
-                                                'f1_span', 'precision_span', 'recall_span',
-                                                'f1_nuclearity', 'precision_nuclearity', 'recall_nuclearity'])
-    results_writer = CsvWriter(file_path=os.path.join(save_dir, 'results.csv'),
-                               fieldnames=['current_epoch', 'loss_tree_test', 'loss_label_test', 'f1_span',
-                                           'f1_relation', 'f1_nuclearity'])
+    best_results_writer = CsvWriter(
+        file_path=os.path.join(save_dir, "best_results.csv"),
+        fieldnames=[
+            "best_epoch",
+            "f1_relation",
+            "precision_relation",
+            "recall_relation",
+            "f1_span",
+            "precision_span",
+            "recall_span",
+            "f1_nuclearity",
+            "precision_nuclearity",
+            "recall_nuclearity",
+        ],
+    )
+    results_writer = CsvWriter(
+        file_path=os.path.join(save_dir, "results.csv"),
+        fieldnames=[
+            "current_epoch",
+            "loss_tree_test",
+            "loss_label_test",
+            "f1_span",
+            "f1_relation",
+            "f1_nuclearity",
+        ],
+    )
 
-    logger.info('Loading training and test data...')
+    logger.info("Loading training and test data...")
     # Load Training data
-    tr_input_sentences = pickle.load(open(os.path.join(train_data_dir, "tokenized_sentences.pickle"), "rb"))
-    tr_edu_breaks = pickle.load(open(os.path.join(train_data_dir, "edu_breaks.pickle"), "rb"))
-    tr_decoder_input = pickle.load(open(os.path.join(train_data_dir, "decoder_input_index.pickle"), "rb"))
-    tr_relation_label = pickle.load(open(os.path.join(train_data_dir, "relation_index.pickle"), "rb"))
-    tr_parsing_breaks = pickle.load(open(os.path.join(train_data_dir, "splits_order.pickle"), "rb"))
-    tr_golden_metric = pickle.load(open(os.path.join(train_data_dir, "discourse_tree_splits.pickle"), "rb"))
-    tr_parents_index = pickle.load(open(os.path.join(train_data_dir, "parent_index.pickle"), "rb"))
-    tr_sibling_index = pickle.load(open(os.path.join(train_data_dir, "sibling_index.pickle"), "rb"))
+    tr_input_sentences = pickle.load(
+        open(os.path.join(train_data_dir, "tokenized_sentences.pickle"), "rb")
+    )
+    tr_edu_breaks = pickle.load(
+        open(os.path.join(train_data_dir, "edu_breaks.pickle"), "rb")
+    )
+    tr_decoder_input = pickle.load(
+        open(os.path.join(train_data_dir, "decoder_input_index.pickle"), "rb")
+    )
+    tr_relation_label = pickle.load(
+        open(os.path.join(train_data_dir, "relation_index.pickle"), "rb")
+    )
+    tr_parsing_breaks = pickle.load(
+        open(os.path.join(train_data_dir, "splits_order.pickle"), "rb")
+    )
+    tr_golden_metric = pickle.load(
+        open(os.path.join(train_data_dir, "discourse_tree_splits.pickle"), "rb")
+    )
+    tr_parents_index = pickle.load(
+        open(os.path.join(train_data_dir, "parent_index.pickle"), "rb")
+    )
+    tr_sibling_index = pickle.load(
+        open(os.path.join(train_data_dir, "sibling_index.pickle"), "rb")
+    )
 
     # Load Testing data
-    test_input_sentences = pickle.load(open(os.path.join(test_data_dir, "tokenized_sentences.pickle"), "rb"))
-    test_edu_breaks = pickle.load(open(os.path.join(test_data_dir, "edu_breaks.pickle"), "rb"))
-    test_decoder_input = pickle.load(open(os.path.join(test_data_dir, "decoder_input_index.pickle"), "rb"))
-    test_relation_label = pickle.load(open(os.path.join(test_data_dir, "relation_index.pickle"), "rb"))
-    test_parsing_breaks = pickle.load(open(os.path.join(test_data_dir, "splits_order.pickle"), "rb"))
-    test_golden_metric = pickle.load(open(os.path.join(test_data_dir, "discourse_tree_splits.pickle"), "rb"))
+    test_input_sentences = pickle.load(
+        open(os.path.join(test_data_dir, "tokenized_sentences.pickle"), "rb")
+    )
+    test_edu_breaks = pickle.load(
+        open(os.path.join(test_data_dir, "edu_breaks.pickle"), "rb")
+    )
+    test_decoder_input = pickle.load(
+        open(os.path.join(test_data_dir, "decoder_input_index.pickle"), "rb")
+    )
+    test_relation_label = pickle.load(
+        open(os.path.join(test_data_dir, "relation_index.pickle"), "rb")
+    )
+    test_parsing_breaks = pickle.load(
+        open(os.path.join(test_data_dir, "splits_order.pickle"), "rb")
+    )
+    test_golden_metric = pickle.load(
+        open(os.path.join(test_data_dir, "discourse_tree_splits.pickle"), "rb")
+    )
 
-    logger.info('--------------------------------------------------------------------')
-    logger.info('Starting model training...')
-    logger.info('--------------------------------------------------------------------')
+    logger.info("--------------------------------------------------------------------")
+    logger.info("Starting model training...")
+    logger.info("--------------------------------------------------------------------")
     # Initialize model
     model_config = RstPointerParserConfig(
         hidden_size=hidden_size,
@@ -345,7 +480,7 @@ def train_parser(cfg: RstPointerParserTrainArgs) -> None:
         dropout_e=dropout_e,
         dropout_d=dropout_d,
         dropout_c=dropout_c,
-        elmo_size=elmo_size
+        elmo_size=elmo_size,
     )
 
     model = RstPointerParserModel(model_config)
@@ -353,8 +488,12 @@ def train_parser(cfg: RstPointerParserTrainArgs) -> None:
 
     preprocessor = RstPreprocessor()
 
-    optimizer = torch.optim.Adam(filter(lambda p: p.requires_grad, model.parameters()),
-                                 lr=lr, betas=(0.9, 0.9), weight_decay=weight_decay)
+    optimizer = torch.optim.Adam(
+        filter(lambda p: p.requires_grad, model.parameters()),
+        lr=lr,
+        betas=(0.9, 0.9),
+        weight_decay=weight_decay,
+    )
 
     num_iterations = int(np.ceil(len(tr_parsing_breaks) / batch_size))
 
@@ -364,18 +503,36 @@ def train_parser(cfg: RstPointerParserTrainArgs) -> None:
         adjust_learning_rate(optimizer, current_epoch, 0.8, lr_decay_epoch)
 
         for current_iteration in range(num_iterations):
-            input_sentences_batch, edu_breaks_batch, decoder_input_batch, \
-            relation_label_batch, parsing_breaks_batch, _, parents_index_batch, \
-            sibling_batch = get_batch_data_training(
-                tr_input_sentences, tr_edu_breaks,
-                tr_decoder_input, tr_relation_label,
-                tr_parsing_breaks, tr_golden_metric,
-                tr_parents_index, tr_sibling_index, batch_size)
+            (
+                input_sentences_batch,
+                edu_breaks_batch,
+                decoder_input_batch,
+                relation_label_batch,
+                parsing_breaks_batch,
+                _,
+                parents_index_batch,
+                sibling_batch,
+            ) = get_batch_data_training(
+                tr_input_sentences,
+                tr_edu_breaks,
+                tr_decoder_input,
+                tr_relation_label,
+                tr_parsing_breaks,
+                tr_golden_metric,
+                tr_parents_index,
+                tr_sibling_index,
+                batch_size,
+            )
 
             model.zero_grad()
 
-            input_sentences_ids_batch, sentence_lengths = preprocessor.get_elmo_char_ids(input_sentences_batch)
-            input_sentences_ids_batch = input_sentences_ids_batch.to(device=model.device)
+            (
+                input_sentences_ids_batch,
+                sentence_lengths,
+            ) = preprocessor.get_elmo_char_ids(input_sentences_batch)
+            input_sentences_ids_batch = input_sentences_ids_batch.to(
+                device=model.device
+            )
 
             loss_tree_batch, loss_label_batch = model.forward_train(
                 input_sentence_ids_batch=input_sentences_ids_batch,
@@ -385,7 +542,7 @@ def train_parser(cfg: RstPointerParserTrainArgs) -> None:
                 decoder_input_index_batch=decoder_input_batch,
                 parents_index_batch=parents_index_batch,
                 sibling_index_batch=sibling_batch,
-                sentence_lengths=sentence_lengths
+                sentence_lengths=sentence_lengths,
             )
 
             loss = loss_tree_batch + loss_label_batch
@@ -393,9 +550,11 @@ def train_parser(cfg: RstPointerParserTrainArgs) -> None:
 
             cur_loss = float(loss.item())
 
-            logger.info(f'Epoch: {current_epoch + 1}/{epochs}, '
-                        f'iteration: {current_iteration + 1}/{num_iterations}, '
-                        f'loss: {cur_loss:.3f}')
+            logger.info(
+                f"Epoch: {current_epoch + 1}/{epochs}, "
+                f"iteration: {current_iteration + 1}/{num_iterations}, "
+                f"loss: {cur_loss:.3f}"
+            )
 
             # To avoid gradient explosion
             torch.nn.utils.clip_grad_norm_(model.parameters(), 5)
@@ -406,10 +565,23 @@ def train_parser(cfg: RstPointerParserTrainArgs) -> None:
         model.eval()
 
         # Eval on Testing data
-        loss_tree_test, loss_label_test, span_points_test, relation_points_test, nuclearity_points_test = \
-            get_accuracy(model, preprocessor, test_input_sentences, test_edu_breaks,
-                         test_decoder_input, test_relation_label,
-                         test_parsing_breaks, test_golden_metric, batch_size)
+        (
+            loss_tree_test,
+            loss_label_test,
+            span_points_test,
+            relation_points_test,
+            nuclearity_points_test,
+        ) = get_accuracy(
+            model,
+            preprocessor,
+            test_input_sentences,
+            test_edu_breaks,
+            test_decoder_input,
+            test_relation_label,
+            test_parsing_breaks,
+            test_golden_metric,
+            batch_size,
+        )
 
         # Unfold numbers
         # Test
@@ -435,14 +607,14 @@ def train_parser(cfg: RstPointerParserTrainArgs) -> None:
 
         # Log evaluation and test metrics
         epoch_metrics = {
-            'current_epoch': current_epoch,
-            'loss_tree_test': loss_tree_test,
-            'loss_label_test': loss_label_test,
-            'f1_span': f1_span,
-            'f1_relation': f1_relation,
-            'f1_nuclearity': f1_nuclearity
+            "current_epoch": current_epoch,
+            "loss_tree_test": loss_tree_test,
+            "loss_label_test": loss_label_test,
+            "f1_span": f1_span,
+            "f1_relation": f1_relation,
+            "f1_nuclearity": f1_nuclearity,
         }
-        logger.info(f'Test metrics: {epoch_metrics}')
+        logger.info(f"Test metrics: {epoch_metrics}")
 
         results_writer.writerow(epoch_metrics)
 
@@ -453,25 +625,27 @@ def train_parser(cfg: RstPointerParserTrainArgs) -> None:
         # Convert back to training
         model.train()
 
-    logger.info('--------------------------------------------------------------------')
-    logger.info('Model training completed!')
-    logger.info('--------------------------------------------------------------------')
-    logger.info(f'The best F1 points for Relation is: {best_f1_relation:.3f}.')
-    logger.info(f'The best F1 points for Nuclearity is: {best_f1_nuclearity:.3f}')
-    logger.info(f'The best F1 points for Span is: {best_f1_span:.3f}')
+    logger.info("--------------------------------------------------------------------")
+    logger.info("Model training completed!")
+    logger.info("--------------------------------------------------------------------")
+    logger.info(f"The best F1 points for Relation is: {best_f1_relation:.3f}.")
+    logger.info(f"The best F1 points for Nuclearity is: {best_f1_nuclearity:.3f}")
+    logger.info(f"The best F1 points for Span is: {best_f1_span:.3f}")
 
-    best_results_writer.writerow({
-        'best_epoch': best_epoch,
-        'f1_relation': best_f1_relation,
-        'precision_relation': best_precision_relation,
-        'recall_relation': best_recall_relation,
-        'f1_span': best_f1_span,
-        'precision_span': best_precision_span,
-        'recall_span': best_recall_span,
-        'f1_nuclearity': best_f1_nuclearity,
-        'precision_nuclearity': best_precision_nuclearity,
-        'recall_nuclearity': best_recall_nuclearity
-    })
+    best_results_writer.writerow(
+        {
+            "best_epoch": best_epoch,
+            "f1_relation": best_f1_relation,
+            "precision_relation": best_precision_relation,
+            "recall_relation": best_recall_relation,
+            "f1_span": best_f1_span,
+            "precision_span": best_precision_span,
+            "recall_span": best_recall_span,
+            "f1_nuclearity": best_f1_nuclearity,
+            "precision_nuclearity": best_precision_nuclearity,
+            "recall_nuclearity": best_recall_nuclearity,
+        }
+    )
 
 
 # Segmenter training code
@@ -599,7 +773,9 @@ def check_accuracy(model, preprocessor, x, y, batch_size):
         if end_idx > len(y):
             end_idx = len(y)
 
-        batch_x, batch_y, all_lens = get_batch_test(x[start_idx:end_idx], y[start_idx:end_idx], None)
+        batch_x, batch_y, all_lens = get_batch_test(
+            x[start_idx:end_idx], y[start_idx:end_idx], None
+        )
 
         input_sentences_ids_batch, _ = preprocessor.get_elmo_char_ids(batch_x)
         input_sentences_ids_batch = input_sentences_ids_batch.to(device=model.device)
@@ -623,12 +799,17 @@ def check_accuracy(model, preprocessor, x, y, batch_size):
     ba_rec = np.sum(all_c) / np.sum(all_g)
     ba_f1 = 2 * ba_pre * ba_rec / (ba_pre + ba_rec)
 
-    return np.mean(all_ave_loss), ba_pre, ba_rec, ba_f1, \
-           (all_x_save, all_index_decoder_y, all_start_boundaries, all_end_boundaries)
+    return (
+        np.mean(all_ave_loss),
+        ba_pre,
+        ba_rec,
+        ba_f1,
+        (all_x_save, all_index_decoder_y, all_start_boundaries, all_end_boundaries),
+    )
 
 
 def train_segmenter(cfg: RstPointerSegmenterTrainArgs) -> None:
-    logger.info(f'===== Training RST Pointer Segmenter =====')
+    logger.info(f"===== Training RST Pointer Segmenter =====")
 
     setup(seed=cfg.seed)
 
@@ -636,8 +817,8 @@ def train_segmenter(cfg: RstPointerSegmenterTrainArgs) -> None:
     test_data_dir = cfg.test_data_dir
     save_dir = cfg.save_dir
 
-    device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
-    logger.info(f'Device: {device}')
+    device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
+    logger.info(f"Device: {device}")
 
     hidden_dim = cfg.hidden_dim
     rnn_type = cfg.rnn
@@ -653,10 +834,14 @@ def train_segmenter(cfg: RstPointerSegmenterTrainArgs) -> None:
     use_bilstm = cfg.use_bilstm
     is_batch_norm = cfg.use_batch_norm
 
-    tr_x = pickle.load(open(os.path.join(train_data_dir, "tokenized_sentences.pickle"), "rb"))
+    tr_x = pickle.load(
+        open(os.path.join(train_data_dir, "tokenized_sentences.pickle"), "rb")
+    )
     tr_y = pickle.load(open(os.path.join(train_data_dir, "edu_breaks.pickle"), "rb"))
 
-    dev_x = pickle.load(open(os.path.join(test_data_dir, "tokenized_sentences.pickle"), "rb"))
+    dev_x = pickle.load(
+        open(os.path.join(test_data_dir, "tokenized_sentences.pickle"), "rb")
+    )
     dev_y = pickle.load(open(os.path.join(test_data_dir, "edu_breaks.pickle"), "rb"))
 
     model_config = RstPointerSegmenterConfig(
@@ -666,7 +851,8 @@ def train_segmenter(cfg: RstPointerSegmenterTrainArgs) -> None:
         num_rnn_layers=num_rnn_layers,
         rnn_type=rnn_type,
         is_batch_norm=is_batch_norm,
-        elmo_size=elmo_size)
+        elmo_size=elmo_size,
+    )
     model = RstPointerSegmenterModel(model_config)
     model.to(device=device)
 
@@ -677,17 +863,31 @@ def train_segmenter(cfg: RstPointerSegmenterTrainArgs) -> None:
 
     test_train_x, test_train_y = sample_batch(tr_x, tr_y, eval_size)
 
-    optimizer = torch.optim.Adam(filter(lambda p: p.requires_grad, model.parameters()), lr=lr,
-                                 weight_decay=wd)
+    optimizer = torch.optim.Adam(
+        filter(lambda p: p.requires_grad, model.parameters()), lr=lr, weight_decay=wd
+    )
 
     num_iterations = int(np.round(len(tr_y) / batch_size))
 
     os.makedirs(save_dir, exist_ok=True)
-    best_results_writer = CsvWriter(file_path=os.path.join(save_dir, 'best_results.csv'),
-                                    fieldnames=["best_epoch", "precision", "recall", "f1"])
-    results_writer = CsvWriter(file_path=os.path.join(save_dir, 'results.csv'),
-                               fieldnames=["current_epoch", "train_loss", "train_precision", "train_recall", "train_f1",
-                                           "dev_loss", "dev_precision", "dev_recall", "dev_f1"])
+    best_results_writer = CsvWriter(
+        file_path=os.path.join(save_dir, "best_results.csv"),
+        fieldnames=["best_epoch", "precision", "recall", "f1"],
+    )
+    results_writer = CsvWriter(
+        file_path=os.path.join(save_dir, "results.csv"),
+        fieldnames=[
+            "current_epoch",
+            "train_loss",
+            "train_precision",
+            "train_recall",
+            "train_f1",
+            "dev_loss",
+            "dev_precision",
+            "dev_recall",
+            "dev_f1",
+        ],
+    )
 
     best_epoch = 0
     best_f1 = 0
@@ -697,22 +897,30 @@ def train_segmenter(cfg: RstPointerSegmenterTrainArgs) -> None:
 
         track_epoch_loss = []
         for current_iter in range(num_iterations):
-            batch_x, batch_x_index, batch_y, all_lens = sample_a_sorted_batch_from_numpy(
-                tr_x, tr_y, batch_size)
+            (
+                batch_x,
+                batch_x_index,
+                batch_y,
+                all_lens,
+            ) = sample_a_sorted_batch_from_numpy(tr_x, tr_y, batch_size)
 
             model.zero_grad()
 
             input_sentences_ids_batch, _ = preprocessor.get_elmo_char_ids(batch_x)
-            input_sentences_ids_batch = input_sentences_ids_batch.to(device=model.device)
+            input_sentences_ids_batch = input_sentences_ids_batch.to(
+                device=model.device
+            )
 
             output = model(input_sentences_ids_batch, all_lens, batch_y)
             loss = output.loss
             loss_value = float(loss.data)
 
             track_epoch_loss.append(loss_value)
-            logger.info(f'Epoch: {current_epoch + 1}/{epochs}, '
-                        f'iteration: {current_iter + 1}/{num_iterations}, '
-                        f'loss: {loss_value:.3f}')
+            logger.info(
+                f"Epoch: {current_epoch + 1}/{epochs}, "
+                f"iteration: {current_iter + 1}/{num_iterations}, "
+                f"loss: {loss_value:.3f}"
+            )
 
             loss.backward()
             torch.nn.utils.clip_grad_norm_(model.parameters(), 5)
@@ -720,18 +928,26 @@ def train_segmenter(cfg: RstPointerSegmenterTrainArgs) -> None:
 
         model.eval()
 
-        logger.info('Running end of epoch evaluations on sample train data and test data...')
-        tr_batch_ave_loss, tr_pre, tr_rec, tr_f1, tr_visdata = check_accuracy(model, preprocessor, test_train_x,
-                                                                              test_train_y, batch_size)
+        logger.info(
+            "Running end of epoch evaluations on sample train data and test data..."
+        )
+        tr_batch_ave_loss, tr_pre, tr_rec, tr_f1, tr_visdata = check_accuracy(
+            model, preprocessor, test_train_x, test_train_y, batch_size
+        )
 
-        dev_batch_ave_loss, dev_pre, dev_rec, dev_f1, dev_visdata = check_accuracy(model, preprocessor, dev_x,
-                                                                                   dev_y, batch_size)
+        dev_batch_ave_loss, dev_pre, dev_rec, dev_f1, dev_visdata = check_accuracy(
+            model, preprocessor, dev_x, dev_y, batch_size
+        )
         _, _, _, all_end_boundaries = dev_visdata
 
-        logger.info(f'train sample -- loss: {tr_batch_ave_loss:.3f}, '
-                    f'precision: {tr_pre:.3f}, recall: {tr_rec:.3f}, f1: {tr_f1:.3f}')
-        logger.info(f'test sample -- loss: {dev_batch_ave_loss:.3f}, '
-                    f'precision: {dev_pre:.3f}, recall: {dev_rec:.3f}, f1: {dev_f1:.3f}')
+        logger.info(
+            f"train sample -- loss: {tr_batch_ave_loss:.3f}, "
+            f"precision: {tr_pre:.3f}, recall: {tr_rec:.3f}, f1: {tr_f1:.3f}"
+        )
+        logger.info(
+            f"test sample -- loss: {dev_batch_ave_loss:.3f}, "
+            f"precision: {dev_pre:.3f}, recall: {dev_rec:.3f}, f1: {dev_f1:.3f}"
+        )
 
         if best_f1 < dev_f1:
             best_f1 = dev_f1
@@ -739,33 +955,37 @@ def train_segmenter(cfg: RstPointerSegmenterTrainArgs) -> None:
             best_pre = dev_pre
             best_epoch = current_epoch
 
-        results_writer.writerow({
-            "current_epoch": current_epoch,
-            "train_loss": tr_batch_ave_loss,
-            "train_precision": tr_pre,
-            "train_recall": tr_rec,
-            "train_f1": tr_f1,
-            "dev_loss": dev_batch_ave_loss,
-            "dev_precision": dev_pre,
-            "dev_recall": dev_rec,
-            "dev_f1": dev_f1
-        })
+        results_writer.writerow(
+            {
+                "current_epoch": current_epoch,
+                "train_loss": tr_batch_ave_loss,
+                "train_precision": tr_pre,
+                "train_recall": tr_rec,
+                "train_f1": tr_f1,
+                "dev_loss": dev_batch_ave_loss,
+                "dev_precision": dev_pre,
+                "dev_recall": dev_rec,
+                "dev_f1": dev_f1,
+            }
+        )
 
         if current_epoch == best_epoch:
-            logger.info('Saving best model...')
+            logger.info("Saving best model...")
             model.save_pretrained(save_dir)
 
-            with open(os.path.join(save_dir, 'best_segmentation.pickle'), 'wb') as f:
+            with open(os.path.join(save_dir, "best_segmentation.pickle"), "wb") as f:
                 pickle.dump(all_end_boundaries, f)
 
         model.train()
 
-    best_results_writer.writerow({
-        'best_epoch': best_epoch,
-        'precision': best_pre,
-        'recall': best_rec,
-        'f1': best_f1
-    })
+    best_results_writer.writerow(
+        {
+            "best_epoch": best_epoch,
+            "precision": best_pre,
+            "recall": best_rec,
+            "f1": best_f1,
+        }
+    )
 
 
 if __name__ == "__main__":
