@@ -1,5 +1,5 @@
 from .config import RumourDetectionTwitterConfig
 from .tokenization import RumourDetectionTwitterTokenizer
 from .modeling import RumourDetectionTwitterModel
-from .train import train
+from .train import train_model
 from .utils import download_tokenizer_files_from_azure
